import { ICreateInstitutionsDTO } from "@modules/institutions/dtos/ICreateInstitutionsDTO";
import { Institutions } from "@prisma/client";
import prismaClient from "@shared/infra/prisma";
import { IInstitutionsRepository } from "../IInstitutionsRepository";

class InstitutionsRepository implements IInstitutionsRepository {
    async create({ name }: ICreateInstitutionsDTO): Promise<Institutions> {
        const institution = await prismaClient.institutions.create({
            data: {
                name
            }
        })
        
        return institution;
    }

    async findById(id: string): Promise<Institutions> {
        const institution = await prismaClient.institutions.findUnique({
            where: {id}
        })

        return institution as Institutions
    }

    async findByName(name: string): Promise<Institutions> {
        const institution = await prismaClient.institutions.findFirst({
            where: {name}
        })

        return institution as Institutions
    }

    async findAllInstitutions(): Promise<Institutions[]> {
        const institutions = await prismaClient.institutions.findMany()
        return institutions
    }

    async deleteInstitutions(id: string): Promise<Boolean> {
        await prismaClient.institutions.delete({
            where: {id}
        })

        return true;
    }
}

export {InstitutionsRepository}